@@ -27,7 +27,7 @@ namespace OTR
 {
     Config::Config()
     {
-        KTpProxyConfig::self()->readConfig();
+        KTpProxyConfig::self()->load();
     }
 
     QString Config::saveLocation()
@@ -71,6 +71,6 @@ namespace OTR
                 KTpProxyConfig::setOTRPolicy(KTpProxyConfig::Never);
                 break;
         }
-        KTpProxyConfig::self()->writeConfig();
+        KTpProxyConfig::self()->save();
     }
 }
